package com.simuwang.manage.api.image;

import com.simuwang.logging.SystemLog;
import com.simuwang.manage.service.ImageSevice;
import com.smppw.common.pojo.ResultVo;
import com.smppw.common.pojo.enums.status.ResultCode;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

@SystemLog(value = "名片管理")
@RestController
@RequestMapping("/v1/image")
public class ImageController {
    @Autowired
    private ImageSevice imageSevice;

    private static final Logger logger = LoggerFactory.getLogger(ImageController.class);
    /**
     * 上传图片
     * @param file
     * @return
     */
    @SystemLog(value = "上传图片", type = SystemLog.Type.UPLOAD_OR_IMPORT)
    @PostMapping("upload")
    public ResultVo upload(@RequestParam("file") MultipartFile file) {
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        try{
            vo = imageSevice.saveImage(file);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setCode(ResultCode.SAVE_FAILED.getCode());
            vo.setMsg(ResultCode.SAVE_FAILED.getMsg());
            vo.setData(false);
        }
        return vo;
    }
    /**
     * 根据文件ID查询文件信息
     * @param fileId
     * @return
     */
    @SystemLog(value = "根据文件ID查询文件信息", type = SystemLog.Type.QUERY)
    @GetMapping("/image-info")
    public ResultVo upload(@RequestParam("fileId") Integer fileId) {
        ResultVo vo = new ResultVo(ResultCode.SAVE_SUCCESS.getCode());
        try{
            vo = imageSevice.getImageById(fileId);
        }catch (Exception e){
            logger.error(e.getMessage(),e);
            vo.setCode(ResultCode.SAVE_FAILED.getCode());
            vo.setMsg(ResultCode.SAVE_FAILED.getMsg());
            vo.setData(false);
        }
        return vo;
    }
}
